from jetline.pipeline.pipeline import Pipeline
from jetline.pipeline.node import Node
from pipelines.example_pipeline.nodes import node_function_1, node_function_2

# Dont change name and directory of __file__ (pipline.py)

# Beispiel für die Registrierung einer Pipeline


def register(data_manager) -> Pipeline:
    # Definieren Sie die Nodes für die Pipeline
    nodes = [
        Node(name='node1', function=node_function_1, inputs=[1, 2,data_manager]),
        Node(name='node2', function=node_function_2, inputs=[1, 2], )
    ]

    # Erstellen und konfigurieren Sie die Pipeline mit den Nodes
    pipeline = Pipeline() 
    for node in nodes:
        pipeline.add_node(node.name, node.function, node.inputs)

    return pipeline



import logging
import coloredlogs

# Logger initialisieren
logger = logging.getLogger(__name__)

# Farben für verschiedene Protokollarten festlegen
level_styles = {
    'debug': {'color': 'white'},
    'info': {'color': 'blue'},
    'warning': {'color': 'yellow'},
    'error': {'color': 'red'},
    'critical': {'color': 'red', 'bold': True}
}

# Einstellungen für coloredlogs installieren
coloredlogs.install(level='DEBUG', logger=logger, fmt='%(message)s', level_styles=level_styles)



from jetline.pipeline.pipeline import PipelineManager
import sys


def run_pipelines():
    """
    Load and execute pipelines defined in the pipeline folder.
    """
    try:
        # Initialize the PipelineManager
        pipeline_manager = PipelineManager()

        # Define the order of pipelines by folder name
        PIPELINE_ORDER = ["example_pipeline"]

        # Execute pipelines
        pipeline_manager.run(PIPELINE_ORDER)

    except Exception as e:
        print(f"Error running pipelines: {e}")
        sys.exit(1)

if __name__ == "__main__":
    run_pipelines()
